import React, {MutableRefObject, useEffect, useRef, useState} from 'react';
import {CrudManagerConfig, SchedulerEventModel, SchedulerResourceModel} from '@bryntum/schedulerpro';
import {BryntumScheduler, BryntumSplitter,} from '@bryntum/schedulerpro-react';
import {schedulerColumns, schedulerConfig} from "./ContentConfig";
import TaskStore from '../lib/TaskStore';
import {Calendar} from "@bryntum/calendar";

const Content = () => {

    // Scheduler and grid refs
    const schedulerRef = useRef<BryntumScheduler>() as MutableRefObject<BryntumScheduler>;
    // CrudManager config
    const [crudManager] = useState<CrudManagerConfig>({
        autoLoad: true,
        eventStore: {
            // @ts-ignore
            storeClass: TaskStore
        },
        transport: {
            load: {
                url: 'data/data.json'
            }
        },
        validateResponse: true
    });

    // Columns config for scheduler
    const [columns] = useState(schedulerColumns);


    // Event context menu feature config. Adds `Unassign` menu item
    const [eventMenuFeature] = useState({
        items: {
            // custom item with inline handler
            unassign: {
                text: 'Unassign',
                icon: 'b-fa b-fa-user-times',
                weight: 200,
                onItem: ({
                    eventRecord,
                    resourceRecord
                }: {
                    eventRecord: SchedulerEventModel;
                    resourceRecord: SchedulerResourceModel;
                }) => eventRecord.unassign(resourceRecord)
            }
        }
    });

    useEffect(() => {
        const calendar = new Calendar({
            date : new Date(2020, 9, 12),
            appendTo : 'cal',
            features : {
                eventTooltip : {
                    align : 'l-r'
                }
            }
        });
    }, []);

    return (
        <>
            <div id="main">
                <BryntumScheduler
                    ref={schedulerRef}
                    eventMenuFeature={eventMenuFeature}
                    eventDragFeature={{ showTooltip: true }}
                    crudManager={crudManager}
                    columns={columns}
                    {...schedulerConfig}
                />
                <BryntumSplitter />
                <div id="cal" />
            </div>
        </>
    );
};

export default Content;
