import { SchedulerResourceModel, GridColumnConfig, StringHelper, SchedulerEventModel } from '@bryntum/schedulerpro';
import { BryntumSchedulerProps, BryntumGridProps } from "@bryntum/schedulerpro-react";

const schedulerConfig: BryntumSchedulerProps = {
    startDate: new Date(2025, 11, 1, 8),
    endDate: new Date(2025, 11, 1, 18),

    rowHeight: 50,
    barMargin: 4,
    eventColor: 'indigo',
    resourceImagePath: 'users/',

    stripeFeature: true,
    timeRangesFeature: true,

    viewPreset: {
        base: 'hourAndDay',
        columnLinesFor: 0,
        headers: [
            {
                unit: 'd',
                align: 'center',
                dateFormat: 'ddd DD MMM'
            },
            {
                unit: 'h',
                align: 'center',
                dateFormat: 'HH'
            }
        ]
    }
};

const schedulerColumns: Partial<GridColumnConfig>[] = [
    {
        type: 'resourceInfo',
        text: 'Name',
        width: 200,
        showEventCount: false,
        showRole: true
    },
    {
        text: 'Nbr tasks',
        editor: false,
        renderer: (data: { record: SchedulerResourceModel; }) => `${data.record.events.length || ''}`,
        align: 'center',
        sortable: (a: SchedulerResourceModel, b: SchedulerResourceModel) =>
            a.events.length < b.events.length ? -1 : 1,
        width: 100
    }
];

const unplannedGridConfig: BryntumGridProps = {
    rowHeight: 50,
    cls: 'b-unplannedgrid',
    columns: [
        {
            text: 'Unassigned tasks',
            flex: 1,
            field: 'name',
            htmlEncode: false,
            renderer: ({ record }: { record: SchedulerEventModel; }) =>
                StringHelper.xss`<i class="${record.iconCls}"></i>${record.name}`
        },
        {
            text: 'Duration',
            width: 100,
            align: 'right',
            editor: false,
            field: 'duration',
            renderer: ({ record }: { record: SchedulerEventModel; }) =>
                StringHelper.xss`${record.duration} ${record.durationUnit}`
        }
    ],
    stripeFeature: true,
    sortFeature: 'name'
};

export { schedulerConfig, schedulerColumns, unplannedGridConfig };
